==> haskell-config-ini-0.2.4.0-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-config-ini.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: config-ini
version: 0.2.4.0
id: config-ini-0.2.4.0-AWKb2qaerMfBKRVHTvea4Z
key: config-ini-0.2.4.0-AWKb2qaerMfBKRVHTvea4Z
license: BSD-3-Clause
copyright: ©2018 Getty Ritter
maintainer: Getty Ritter <config-ini@infinitenegativeutility.com>
author: Getty Ritter <config-ini@infinitenegativeutility.com>
homepage: https://github.com/aisamanra/config-ini
synopsis: A library for simple INI-based configuration files.
description:
    The @config-ini@ library is a set of small monadic languages
    for writing simple configuration languages with convenient,
    human-readable error messages.
    .
    > parseConfig :: IniParser (Text, Int, Bool)
    > parseConfig = section "NETWORK" $ do
    >   user <- field        "user"
    >   port <- fieldOf      "port" number
    >   enc  <- fieldFlagDef "encryption" True
    >   return (user, port, enc)
category: Configuration
abi: 3c52755fbe440431c033d7bb8c214229
exposed: True
exposed-modules:
    Data.Ini.Config Data.Ini.Config.Bidir Data.Ini.Config.Raw
import-dirs: /usr/lib/ghc-8.6.3/site-local/config-ini-0.2.4.0
library-dirs: /usr/lib/ghc-8.6.3/site-local/config-ini-0.2.4.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/config-ini-0.2.4.0
hs-libraries: HSconfig-ini-0.2.4.0-AWKb2qaerMfBKRVHTvea4Z
depends:
    base-4.12.0.0 containers-0.6.0.1
    megaparsec-7.0.4-6kTw2XktLyrJEOPPrniUVY text-1.2.3.1
    transformers-0.5.5.0
    unordered-containers-0.2.9.0-BISrknrydugK8yp2XIgTJd
haddock-interfaces: /usr/share/doc/haskell-config-ini/html/config-ini.haddock
haddock-html: /usr/share/doc/haskell-config-ini/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-config-ini-0.2.4.0-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-config-ini.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: config-ini
version: 0.2.4.0
id: config-ini-0.2.4.0-2TyiNvQfX2lFNPrewpjGIw
key: config-ini-0.2.4.0-2TyiNvQfX2lFNPrewpjGIw
license: BSD-3-Clause
copyright: ©2018 Getty Ritter
maintainer: Getty Ritter <config-ini@infinitenegativeutility.com>
author: Getty Ritter <config-ini@infinitenegativeutility.com>
homepage: https://github.com/aisamanra/config-ini
synopsis: A library for simple INI-based configuration files.
description:
    The @config-ini@ library is a set of small monadic languages
    for writing simple configuration languages with convenient,
    human-readable error messages.
    .
    > parseConfig :: IniParser (Text, Int, Bool)
    > parseConfig = section "NETWORK" $ do
    >   user <- field        "user"
    >   port <- fieldOf      "port" number
    >   enc  <- fieldFlagDef "encryption" True
    >   return (user, port, enc)
category: Configuration
abi: 9069b1deac5c4aa310d1b6f2d7e36f45
exposed: True
exposed-modules:
    Data.Ini.Config Data.Ini.Config.Bidir Data.Ini.Config.Raw
import-dirs: /usr/lib/ghc-8.6.3/site-local/config-ini-0.2.4.0
library-dirs: /usr/lib/ghc-8.6.3/site-local/config-ini-0.2.4.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/config-ini-0.2.4.0
hs-libraries: HSconfig-ini-0.2.4.0-2TyiNvQfX2lFNPrewpjGIw
depends:
    base-4.12.0.0 containers-0.6.0.1
    megaparsec-7.0.4-9rIQSae42E1WcXWRr61ak text-1.2.3.1
    transformers-0.5.5.0
    unordered-containers-0.2.10.0-HO72tBDce9GHcBPxpae42I
haddock-interfaces: /usr/share/doc/haskell-config-ini/html/config-ini.haddock
haddock-html: /usr/share/doc/haskell-config-ini/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
